# Mercury Extension for JupyterLab

Develop web apps from Python notebooks with Mercury directly in JupyterLab.

## Install

To install the extension, execute:

```bash
pip install mercuryextension
```

## Uninstall

To remove the extension, execute:

```bash
pip uninstall mercuryextension
```

